@@ -3,13 +3,13 @@
 import tensorflow as tf
 from tensorflow.keras import backend as K
 
+
 def iou_loss(y_true, y_pred):
-    """Computes a variation of the loss 1 - IoU, the difference being the inclusion of the 'smooth' parameter to ensure
-     no division by zero, and a scaling parameter to ensure IoU scores in the range [0, 1].
+    """Computes the IoU for a single target class, then return a loss score between [0, 1].
 
     Args:
-        y_true: tensor of ground-truth values of size (batch, height, width, 2);
-        y_pred: tensor of model predictions of size (batch, height, width, 2), so one-hot encoded."""
+        y_true: tensor of ground-truth values of size (batch, height, width);
+        y_pred: tensor of model predictions of size (batch, height, width)."""
 
     y_true = tf.cast(y_true, tf.float32)
     y_pred = tf.cast(y_pred, tf.float32)
